window.Gleam.initSearch([{"doc":"glbencode","title":"glbencode","content":"\n# GLBEncode\n\nGLBEncode is a Gleam library for encoding and decoding Bencode data. Bencode is a simple encoding format used by the BitTorrent protocol for storing and transmitting loosely structured data.\n\n## Features\n\n- **Parsing**: Convert Bencode data into an intermediate representation.\n- **Encoding**: Convert the intermediate representation back into Bencode format.\n- **Decoding**: Convert the intermediate representation into dynamic Gleam types for further processing.\n\n## Installation\n\nTo use GLBEncode in your Gleam project, add it to your `gleam.toml` dependencies:\n\n```toml\n[dependencies]\nglbencode = &quot;1.0.0&quot;\n```\n\n## Usage\n\n### Parsing Bencode Data\n\nYou can parse Bencode data from a string or a byte array:\n\n```gleam\nimport glbencode\nimport gleam/result.{Ok, Error}\n\nlet bencode_string = &quot;d3:cow3:moo4:spam4:eggse&quot;\nlet parsed = glbencode.parse(bencode_string)\n\ncase parsed {\n  Ok(value) -&gt; // Handle the parsed value\n  Error(error) -&gt; // Handle the error\n}\n```\n\n### Encoding Bencode Data\n\nYou can encode data into Bencode format:\n\n```gleam\nimport glbencode/encode\n\nlet encoder = encode.new()\nlet encoder = encode.dictionary(encoder, fn(_) {\n  dict.from_list([#(&quot;cow&quot;, encode.string_value(&quot;moo&quot;)), #(&quot;spam&quot;, encode.string_value(&quot;eggs&quot;))])\n})\nlet encoded = encode.encode(encoder)\n\ncase encoded {\n  Ok(bytes) -&gt; // Handle the encoded bytes\n  Error(error) -&gt; // Handle the error\n}\n```\n\n### Decoding Bencode Data\n\nYou can decode Bencode data into dynamic Gleam types:\n\n```gleam\nimport glbencode\nimport gleam/dynamic/decode as dyn_decoder\n\nlet bencode_string = &quot;d3:cow3:moo4:spam4:eggse&quot;\nlet parsed = glbencode.parse(bencode_string)\n\ncase parsed {\n  Ok(value) -&gt; {\n    let decoder = dyn_decoder.string()\n    let decoded = glbencode.decode(value, decoder)\n    // Handle the decoded value\n  }\n  Error(error) -&gt; // Handle the error\n}\n```\n\n\n## Contributing\n\nContributions are welcome! Please open an issue or submit a pull request on GitHub.\n\n## License\n\nThis project is licensed under the MIT License.\n","url":"index.html"},{"doc":"bencode/intermediate","title":"TokenAST","content":"pub type TokenAST {\n  IntToken(Int)\n  StringToken(BitArray)\n  DictionaryToken(Dict(String, TokenAST))\n  ListToken(List(TokenAST))\n}\n\nIntToken(Int)\n\n\nStringToken(BitArray)\n\n\nDictionaryToken(Dict(String, TokenAST))\n\n\nListToken(List(TokenAST))\n\n\nSynonyms:\nbencode/intermediate.TokenAST\nbencode/intermediate TokenAST","url":"bencode/intermediate.html#TokenAST"},{"doc":"bencode/intermediate","title":"bencode/intermediate","content":"","url":"bencode/intermediate.html"},{"doc":"bencode/decode","title":"Root","content":"pub type Root =\n  intermediate.TokenAST\n\n\nSynonyms:\nbencode/decode.Root\nbencode/decode Root","url":"bencode/decode.html#Root"},{"doc":"bencode/decode","title":"decode","content":"pub fn decode(\n  in: TokenAST,\n  deocder: Decoder(a),\n) -&gt; Result(a, List(DecodeError))\n\nSynonyms:\nbencode/decode.decode\nbencode/decode decode","url":"bencode/decode.html#decode"},{"doc":"bencode/decode","title":"to_dynamic","content":"pub fn to_dynamic(in: TokenAST) -&gt; Dynamic\n\nSynonyms:\nbencode/decode.to_dynamic\nbencode/decode to_dynamic","url":"bencode/decode.html#to_dynamic"},{"doc":"bencode/decode","title":"bencode/decode","content":"","url":"bencode/decode.html"},{"doc":"bencode/encode","title":"EncoderError","content":"pub type EncoderError {\n  UnexpectedInput\n  UnexpectedRootElements\n}\n\nUnexpectedInput\n\n\nUnexpectedRootElements\n\n\nSynonyms:\nbencode/encode.EncoderError\nbencode/encode EncoderError","url":"bencode/encode.html#EncoderError"},{"doc":"bencode/encode","title":"bytes","content":"pub fn bytes(\n  in: List(TokenAST),\n  contents: BitArray,\n) -&gt; List(TokenAST)\n\nSynonyms:\nbencode/encode.bytes\nbencode/encode bytes","url":"bencode/encode.html#bytes"},{"doc":"bencode/encode","title":"bytes_value","content":"pub fn bytes_value(contents: BitArray) -&gt; TokenAST\n\nSynonyms:\nbencode/encode.bytes_value\nbencode/encode bytes_value","url":"bencode/encode.html#bytes_value"},{"doc":"bencode/encode","title":"dict_value","content":"pub fn dict_value(\n  contents: fn(Dict(String, TokenAST)) -&gt; Dict(String, TokenAST),\n) -&gt; TokenAST\n\nSynonyms:\nbencode/encode.dict_value\nbencode/encode dict_value","url":"bencode/encode.html#dict_value"},{"doc":"bencode/encode","title":"dictionary","content":"pub fn dictionary(\n  in: List(TokenAST),\n  content: fn(Dict(String, TokenAST)) -&gt; Dict(String, TokenAST),\n) -&gt; List(TokenAST)\n\nSynonyms:\nbencode/encode.dictionary\nbencode/encode dictionary","url":"bencode/encode.html#dictionary"},{"doc":"bencode/encode","title":"encode","content":"pub fn encode(\n  in: List(TokenAST),\n) -&gt; Result(BitArray, EncoderError)\n\nSynonyms:\nbencode/encode.encode\nbencode/encode encode","url":"bencode/encode.html#encode"},{"doc":"bencode/encode","title":"int","content":"pub fn int(in: List(TokenAST), contents: Int) -&gt; List(TokenAST)\n\nSynonyms:\nbencode/encode.int\nbencode/encode int","url":"bencode/encode.html#int"},{"doc":"bencode/encode","title":"int_value","content":"pub fn int_value(contents: Int) -&gt; TokenAST\n\nSynonyms:\nbencode/encode.int_value\nbencode/encode int_value","url":"bencode/encode.html#int_value"},{"doc":"bencode/encode","title":"list","content":"pub fn list(\n  in: List(TokenAST),\n  contents: List(TokenAST),\n) -&gt; List(TokenAST)\n\nSynonyms:\nbencode/encode.list\nbencode/encode list","url":"bencode/encode.html#list"},{"doc":"bencode/encode","title":"list_value","content":"pub fn list_value(contents: List(TokenAST)) -&gt; TokenAST\n\nSynonyms:\nbencode/encode.list_value\nbencode/encode list_value","url":"bencode/encode.html#list_value"},{"doc":"bencode/encode","title":"new","content":"pub fn new() -&gt; List(TokenAST)\n\nSynonyms:\nbencode/encode.new\nbencode/encode new","url":"bencode/encode.html#new"},{"doc":"bencode/encode","title":"string","content":"pub fn string(\n  in: List(TokenAST),\n  contents: String,\n) -&gt; List(TokenAST)\n\nSynonyms:\nbencode/encode.string\nbencode/encode string","url":"bencode/encode.html#string"},{"doc":"bencode/encode","title":"string_value","content":"pub fn string_value(contents: String) -&gt; TokenAST\n\nSynonyms:\nbencode/encode.string_value\nbencode/encode string_value","url":"bencode/encode.html#string_value"},{"doc":"bencode/encode","title":"bencode/encode","content":"","url":"bencode/encode.html"},{"doc":"bencode/parser","title":"DecoderError","content":"pub type DecoderError {\n  EOF\n  ParseError(String)\n  UnexpectedError\n  IllegalCharacter\n  UnknownToken(String)\n}\n\nEOF\n\n\nParseError(String)\n\n\nUnexpectedError\n\n\nIllegalCharacter\n\n\nUnknownToken(String)\n\n\nSynonyms:\nbencode/parser.DecoderError\nbencode/parser DecoderError","url":"bencode/parser.html#DecoderError"},{"doc":"bencode/parser","title":"binary_string","content":"pub fn binary_string(\n  in: BitArray,\n) -&gt; Result(#(BitArray, TokenAST), DecoderError)\n\nSynonyms:\nbencode/parser.binary_string\nbencode/parser binary_string","url":"bencode/parser.html#binary_string"},{"doc":"bencode/parser","title":"dicrionary","content":"pub fn dicrionary(\n  in: BitArray,\n) -&gt; Result(#(BitArray, TokenAST), DecoderError)\n\nSynonyms:\nbencode/parser.dicrionary\nbencode/parser dicrionary","url":"bencode/parser.html#dicrionary"},{"doc":"bencode/parser","title":"int","content":"pub fn int(\n  in: BitArray,\n) -&gt; Result(#(BitArray, TokenAST), DecoderError)\n\nSynonyms:\nbencode/parser.int\nbencode/parser int","url":"bencode/parser.html#int"},{"doc":"bencode/parser","title":"list","content":"pub fn list(\n  in: BitArray,\n) -&gt; Result(#(BitArray, TokenAST), DecoderError)\n\nSynonyms:\nbencode/parser.list\nbencode/parser list","url":"bencode/parser.html#list"},{"doc":"bencode/parser","title":"lookahead","content":"pub fn lookahead(\n  in: BitArray,\n  lambda: fn(String, BitArray) -&gt; Result(a, DecoderError),\n) -&gt; Result(a, DecoderError)\n\nSynonyms:\nbencode/parser.lookahead\nbencode/parser lookahead","url":"bencode/parser.html#lookahead"},{"doc":"bencode/parser","title":"parse","content":"pub fn parse(in: BitArray) -&gt; Result(TokenAST, DecoderError)\n\nSynonyms:\nbencode/parser.parse\nbencode/parser parse","url":"bencode/parser.html#parse"},{"doc":"bencode/parser","title":"take","content":"pub fn take(\n  in: BitArray,\n  amount: Int,\n) -&gt; Result(#(BitArray, BitArray), DecoderError)\n\nSynonyms:\nbencode/parser.take\nbencode/parser take","url":"bencode/parser.html#take"},{"doc":"bencode/parser","title":"take_while","content":"pub fn take_while(\n  in: BitArray,\n  predicate: fn(String) -&gt; Bool,\n) -&gt; #(BitArray, BitArray)\n\nSynonyms:\nbencode/parser.take_while\nbencode/parser take_while","url":"bencode/parser.html#take_while"},{"doc":"bencode/parser","title":"bencode/parser","content":"","url":"bencode/parser.html"},{"doc":"glbencode","title":"decode","content":"pub fn decode(\n  in: TokenAST,\n  decoder: Decoder(a),\n) -&gt; Result(a, List(DecodeError))\n\nSynonyms:\nglbencode.decode\nglbencode decode","url":"glbencode.html#decode"},{"doc":"glbencode","title":"encode","content":"pub fn encode(in: TokenAST) -&gt; Result(BitArray, EncoderError)\n\nSynonyms:\nglbencode.encode\nglbencode encode","url":"glbencode.html#encode"},{"doc":"glbencode","title":"parse","content":"pub fn parse(in: String) -&gt; Result(TokenAST, DecoderError)\n\nSynonyms:\nglbencode.parse\nglbencode parse","url":"glbencode.html#parse"},{"doc":"glbencode","title":"parse_byte","content":"pub fn parse_byte(in: BitArray) -&gt; Result(TokenAST, DecoderError)\n\nSynonyms:\nglbencode.parse_byte\nglbencode parse_byte","url":"glbencode.html#parse_byte"},{"doc":"glbencode","title":"glbencode","content":"","url":"glbencode.html"}]);